@@ -341,7 +341,7 @@ int main( int argc, char *argv[] )
 
     static const char description[] = I18N_NOOP( "The KDevelop Integrated Development Environment" );
     KAboutData aboutData( "kdevelop", i18n( "KDevelop" ), QByteArray(VERSION), i18n(description), KAboutLicense::GPL,
-                          i18n("Copyright 1999-2016, The KDevelop developers"), QString(), "http://www.kdevelop.org/");
+                          i18n("Copyright 1999-2017, The KDevelop developers"), QString(), "http://www.kdevelop.org/");
     aboutData.setDesktopFileName(QStringLiteral("org.kde.kdevelop"));
     aboutData.addAuthor( i18n("Kevin Funk"), i18n( "Co-maintainer, C++/Clang, QA, Windows Support" ), "kfunk@kde.org" );
     aboutData.addAuthor( i18n("Sven Brauch"), i18n( "Co-maintainer, AppImage, Python Support, User Interface improvements" ), "svenbrauch@gmail.com" );
@@ -405,7 +405,8 @@ int main( int argc, char *argv[] )
 
     KAboutData::setApplicationData(aboutData);
     // set icon for shells which do not use desktop file metadata
-    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kdevelop")));
+    // but without setting replacing an existing icon with an empty one!
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kdevelop"), QApplication::windowIcon()));
 
     KCrash::initialize();
 
