@@ -24,6 +24,7 @@
 #include <QDialog>
 
 class KSysGuardProcessList;
+class QItemSelection;
 class QPushButton;
 
 namespace KDevMI {
@@ -38,7 +39,7 @@ class ProcessSelectionDialog : public QDialog
         QSize sizeHint() const override;
 
     private slots:
-        void selectionChanged();
+        void selectionChanged( const QItemSelection& selected );
 
     private:
         KSysGuardProcessList* m_processList;
