@@ -39,11 +39,14 @@ class ILaunchConfiguration;
 class IProject;
 }
 
-namespace GDBDebugger
+namespace KDevMI
+{
+namespace GDB
 {
 class CppDebuggerPlugin;
 class DebugSession;
 }
+}
 
 class GdbConfigPageFactory : public KDevelop::LaunchConfigurationPageFactory
 {
@@ -55,11 +58,11 @@ class GdbConfigPage : public KDevelop::LaunchConfigurationPage
 {
 Q_OBJECT
 public:
-    GdbConfigPage( QWidget* parent = 0 );
+    GdbConfigPage( QWidget* parent = nullptr );
     ~GdbConfigPage() override;
     QIcon icon() const override;
-    void loadFromConfiguration(const KConfigGroup& cfg, KDevelop::IProject* = 0) override;
-    void saveToConfiguration(KConfigGroup, KDevelop::IProject* = 0 ) const override;
+    void loadFromConfiguration(const KConfigGroup& cfg, KDevelop::IProject* = nullptr) override;
+    void saveToConfiguration(KConfigGroup, KDevelop::IProject* = nullptr ) const override;
     QString title() const override;
 private:
     Ui::GdbConfigPage* ui;
@@ -68,7 +71,7 @@ private:
 class GdbLauncher : public KDevelop::ILauncher
 {
 public:
-    GdbLauncher( GDBDebugger::CppDebuggerPlugin* plugin, IExecutePlugin* execute );
+    GdbLauncher( KDevMI::GDB::CppDebuggerPlugin* plugin, IExecutePlugin* execute );
     QList< KDevelop::LaunchConfigurationPageFactory* > configPages() const override;
     QString description() const override;
     QString id() override;
@@ -77,7 +80,7 @@ public:
     QStringList supportedModes() const override;
 private:
     QList<KDevelop::LaunchConfigurationPageFactory*> factoryList;
-    GDBDebugger::CppDebuggerPlugin* m_plugin;
+    QPointer<KDevMI::GDB::CppDebuggerPlugin> m_plugin;
     IExecutePlugin* m_execute;
 };
 
