@@ -305,7 +305,7 @@ void MemoryView::contextMenuEvent(QContextMenuEvent *e)
     KHE::BytesEditInterface *bytesEdit = KHE::bytesEditInterface(khexedit2_widget);
     KHE::ValueColumnInterface *valueColumn = KHE::valueColumnInterface(khexedit2_widget);
 
-    QMenu menu;
+    QMenu menu(this);
 
     bool app_running = !(debuggerState_ & s_appNotStarted);
 
@@ -318,7 +318,7 @@ void MemoryView::contextMenuEvent(QContextMenuEvent *e)
     if (valueColumn)
     {
         // make Format menu with action group
-        QMenu *formatMenu = new QMenu(i18n("&Format"));
+        QMenu* formatMenu = menu.addMenu(i18n("&Format"));
         formatGroup = new QActionGroup(formatMenu);
 
         QAction *binary = formatGroup->addAction(i18n("&Binary"));
@@ -348,11 +348,9 @@ void MemoryView::contextMenuEvent(QContextMenuEvent *e)
             act->setShortcutContext(Qt::WidgetWithChildrenShortcut);
         }
 
-        menu.addMenu(formatMenu);
-
 
         // make Grouping menu with action group
-        QMenu *groupingMenu = new QMenu(i18n("&Grouping"));
+        QMenu* groupingMenu = menu.addMenu(i18n("&Grouping"));
         groupingGroup = new QActionGroup(groupingMenu);
 
         QAction *group0 = groupingGroup->addAction(i18n("&0"));
@@ -391,8 +389,6 @@ void MemoryView::contextMenuEvent(QContextMenuEvent *e)
             act->setChecked(act->data().toInt() == valueColumn->noOfGroupedBytes());
             act->setShortcutContext(Qt::WidgetWithChildrenShortcut);
         }
-
-        menu.addMenu(groupingMenu);
     }
 
     QAction* write = menu.addAction(i18n("Write changes"));
@@ -448,7 +444,7 @@ void MemoryView::contextMenuEvent(QContextMenuEvent *e)
     }
 
     if (result == close)
-        delete this;
+        deleteLater();
 }
 
 bool MemoryView::isOk() const
