@@ -1080,29 +1080,29 @@ void LldbTest::testStack()
 
     QCOMPARE(stackModel->rowCount(tIdx), 4);
     QCOMPARE(stackModel->columnCount(tIdx), 3);
-    COMPARE_DATA(tIdx.child(0, 0), "0");
-    COMPARE_DATA(tIdx.child(0, 1), "foo()");
-    COMPARE_DATA(tIdx.child(0, 2), m_debugeeFileName+":23");
-    COMPARE_DATA(tIdx.child(1, 0), "1");
-    COMPARE_DATA(tIdx.child(1, 1), "main");
-    COMPARE_DATA(tIdx.child(1, 2), m_debugeeFileName+":29");
-    COMPARE_DATA(tIdx.child(2, 0), "2");
-    COMPARE_DATA(tIdx.child(2, 1), "__libc_start_main");
-    COMPARE_DATA(tIdx.child(3, 0), "3");
-    COMPARE_DATA(tIdx.child(3, 1), "_start");
+    COMPARE_DATA(stackModel->index(0, 0, tIdx), "0");
+    COMPARE_DATA(stackModel->index(0, 1, tIdx), "foo()");
+    COMPARE_DATA(stackModel->index(0, 2, tIdx), m_debugeeFileName+":23");
+    COMPARE_DATA(stackModel->index(1, 0, tIdx), "1");
+    COMPARE_DATA(stackModel->index(1, 1, tIdx), "main");
+    COMPARE_DATA(stackModel->index(1, 2, tIdx), m_debugeeFileName+":29");
+    COMPARE_DATA(stackModel->index(2, 0, tIdx), "2");
+    COMPARE_DATA(stackModel->index(2, 1, tIdx), "__libc_start_main");
+    COMPARE_DATA(stackModel->index(3, 0, tIdx), "3");
+    COMPARE_DATA(stackModel->index(3, 1, tIdx), "_start");
 
 
     session->stepOut();
     WAIT_FOR_STATE_AND_IDLE(session, DebugSession::PausedState);
     COMPARE_DATA(tIdx, "#1 at main");
     QCOMPARE(stackModel->rowCount(tIdx), 3);
-    COMPARE_DATA(tIdx.child(0, 0), "0");
-    COMPARE_DATA(tIdx.child(0, 1), "main");
-    COMPARE_DATA(tIdx.child(0, 2), m_debugeeFileName+":30");
-    COMPARE_DATA(tIdx.child(1, 0), "1");
-    COMPARE_DATA(tIdx.child(1, 1), "__libc_start_main");
-    COMPARE_DATA(tIdx.child(2, 0), "2");
-    COMPARE_DATA(tIdx.child(2, 1), "_start");
+    COMPARE_DATA(stackModel->index(0, 0, tIdx), "0");
+    COMPARE_DATA(stackModel->index(0, 1, tIdx), "main");
+    COMPARE_DATA(stackModel->index(0, 2, tIdx), m_debugeeFileName+":30");
+    COMPARE_DATA(stackModel->index(1, 0, tIdx), "1");
+    COMPARE_DATA(stackModel->index(1, 1, tIdx), "__libc_start_main");
+    COMPARE_DATA(stackModel->index(2, 0, tIdx), "2");
+    COMPARE_DATA(stackModel->index(2, 1, tIdx), "_start");
 
     session->run();
     WAIT_FOR_STATE_AND_IDLE(session, DebugSession::PausedState);
@@ -1131,52 +1131,52 @@ void LldbTest::testStackFetchMore()
     COMPARE_DATA(tIdx, "#1 at foo()");
 
     QCOMPARE(stackModel->rowCount(tIdx), 21);
-    COMPARE_DATA(tIdx.child(0, 0), "0");
-    COMPARE_DATA(tIdx.child(0, 1), "foo()");
-    COMPARE_DATA(tIdx.child(0, 2), fileName+":26");
-    COMPARE_DATA(tIdx.child(1, 0), "1");
-    COMPARE_DATA(tIdx.child(1, 1), "foo()");
-    COMPARE_DATA(tIdx.child(1, 2), fileName+":24");
-    COMPARE_DATA(tIdx.child(2, 0), "2");
-    COMPARE_DATA(tIdx.child(2, 1), "foo()");
-    COMPARE_DATA(tIdx.child(2, 2), fileName+":24");
-    COMPARE_DATA(tIdx.child(19, 0), "19");
-    COMPARE_DATA(tIdx.child(20, 0), "20");
+    COMPARE_DATA(stackModel->index(0, 0, tIdx), "0");
+    COMPARE_DATA(stackModel->index(0, 1, tIdx), "foo()");
+    COMPARE_DATA(stackModel->index(0, 2, tIdx), fileName+":26");
+    COMPARE_DATA(stackModel->index(1, 0, tIdx), "1");
+    COMPARE_DATA(stackModel->index(1, 1, tIdx), "foo()");
+    COMPARE_DATA(stackModel->index(1, 2, tIdx), fileName+":24");
+    COMPARE_DATA(stackModel->index(2, 0, tIdx), "2");
+    COMPARE_DATA(stackModel->index(2, 1, tIdx), "foo()");
+    COMPARE_DATA(stackModel->index(2, 2, tIdx), fileName+":24");
+    COMPARE_DATA(stackModel->index(19, 0, tIdx), "19");
+    COMPARE_DATA(stackModel->index(20, 0, tIdx), "20");
 
     stackModel->fetchMoreFrames();
     WAIT_FOR_A_WHILE(session, 200);
     QCOMPARE(stackModel->fetchFramesCalled, 2);
     QCOMPARE(stackModel->rowCount(tIdx), 41);
-    COMPARE_DATA(tIdx.child(20, 0), "20");
-    COMPARE_DATA(tIdx.child(21, 0), "21");
-    COMPARE_DATA(tIdx.child(22, 0), "22");
-    COMPARE_DATA(tIdx.child(39, 0), "39");
-    COMPARE_DATA(tIdx.child(40, 0), "40");
+    COMPARE_DATA(stackModel->index(20, 0, tIdx), "20");
+    COMPARE_DATA(stackModel->index(21, 0, tIdx), "21");
+    COMPARE_DATA(stackModel->index(22, 0, tIdx), "22");
+    COMPARE_DATA(stackModel->index(39, 0, tIdx), "39");
+    COMPARE_DATA(stackModel->index(40, 0, tIdx), "40");
 
     stackModel->fetchMoreFrames();
     WAIT_FOR_A_WHILE(session, 200);
     QCOMPARE(stackModel->fetchFramesCalled, 3);
     QCOMPARE(stackModel->rowCount(tIdx), 121);
-    COMPARE_DATA(tIdx.child(40, 0), "40");
-    COMPARE_DATA(tIdx.child(41, 0), "41");
-    COMPARE_DATA(tIdx.child(42, 0), "42");
-    COMPARE_DATA(tIdx.child(119, 0), "119");
-    COMPARE_DATA(tIdx.child(120, 0), "120");
+    COMPARE_DATA(stackModel->index(40, 0, tIdx), "40");
+    COMPARE_DATA(stackModel->index(41, 0, tIdx), "41");
+    COMPARE_DATA(stackModel->index(42, 0, tIdx), "42");
+    COMPARE_DATA(stackModel->index(119, 0, tIdx), "119");
+    COMPARE_DATA(stackModel->index(120, 0, tIdx), "120");
 
     stackModel->fetchMoreFrames();
     WAIT_FOR_A_WHILE(session, 200);
     QCOMPARE(stackModel->fetchFramesCalled, 4);
     QCOMPARE(stackModel->rowCount(tIdx), 301);
-    COMPARE_DATA(tIdx.child(120, 0), "120");
-    COMPARE_DATA(tIdx.child(121, 0), "121");
-    COMPARE_DATA(tIdx.child(122, 0), "122");
-    COMPARE_DATA(tIdx.child(298, 0), "298");
-    COMPARE_DATA(tIdx.child(298, 1), "main");
-    COMPARE_DATA(tIdx.child(298, 2), fileName+":30");
-    COMPARE_DATA(tIdx.child(299, 0), "299");
-    COMPARE_DATA(tIdx.child(299, 1), "__libc_start_main");
-    COMPARE_DATA(tIdx.child(300, 0), "300");
-    COMPARE_DATA(tIdx.child(300, 1), "_start");
+    COMPARE_DATA(stackModel->index(120, 0, tIdx), "120");
+    COMPARE_DATA(stackModel->index(121, 0, tIdx), "121");
+    COMPARE_DATA(stackModel->index(122, 0, tIdx), "122");
+    COMPARE_DATA(stackModel->index(298, 0, tIdx), "298");
+    COMPARE_DATA(stackModel->index(298, 1, tIdx), "main");
+    COMPARE_DATA(stackModel->index(298, 2, tIdx), fileName+":30");
+    COMPARE_DATA(stackModel->index(299, 0, tIdx), "299");
+    COMPARE_DATA(stackModel->index(299, 1, tIdx), "__libc_start_main");
+    COMPARE_DATA(stackModel->index(300, 0, tIdx), "300");
+    COMPARE_DATA(stackModel->index(300, 1, tIdx), "_start");
 
     stackModel->fetchMoreFrames(); //nothing to fetch, we are at the end
     WAIT_FOR_A_WHILE(session, 200);
@@ -1204,13 +1204,13 @@ void LldbTest::testStackDeactivateAndActive()
     WAIT_FOR_STATE_AND_IDLE(session, DebugSession::PausedState);
     COMPARE_DATA(tIdx, "#1 at main");
     QCOMPARE(stackModel->rowCount(tIdx), 3);
-    COMPARE_DATA(tIdx.child(0, 0), "0");
-    COMPARE_DATA(tIdx.child(0, 1), "main");
-    COMPARE_DATA(tIdx.child(0, 2), m_debugeeFileName+":30");
-    COMPARE_DATA(tIdx.child(1, 0), "1");
-    COMPARE_DATA(tIdx.child(1, 1), "__libc_start_main");
-    COMPARE_DATA(tIdx.child(2, 0), "2");
-    COMPARE_DATA(tIdx.child(2, 1), "_start");
+    COMPARE_DATA(stackModel->index(0, 0, tIdx), "0");
+    COMPARE_DATA(stackModel->index(0, 1, tIdx), "main");
+    COMPARE_DATA(stackModel->index(0, 2, tIdx), m_debugeeFileName+":30");
+    COMPARE_DATA(stackModel->index(1, 0, tIdx), "1");
+    COMPARE_DATA(stackModel->index(1, 1, tIdx), "__libc_start_main");
+    COMPARE_DATA(stackModel->index(2, 0, tIdx), "2");
+    COMPARE_DATA(stackModel->index(2, 1, tIdx), "_start");
 
     session->run();
     WAIT_FOR_STATE_AND_IDLE(session, DebugSession::PausedState);
@@ -1237,9 +1237,9 @@ void LldbTest::testStackSwitchThread()
     QModelIndex tIdx = stackModel->index(0,0);
     COMPARE_DATA(tIdx, "#1 at main");
     QCOMPARE(stackModel->rowCount(tIdx), 1);
-    COMPARE_DATA(tIdx.child(0, 0), "0");
-    COMPARE_DATA(tIdx.child(0, 1), "main");
-    COMPARE_DATA(tIdx.child(0, 2), fileName+":39");
+    COMPARE_DATA(stackModel->index(0, 0, tIdx), "0");
+    COMPARE_DATA(stackModel->index(0, 1, tIdx), "main");
+    COMPARE_DATA(stackModel->index(0, 2, tIdx), fileName+":39");
 
     tIdx = stackModel->index(1,0);
     QVERIFY(stackModel->data(tIdx).toString().startsWith("#2 at "));
@@ -1676,26 +1676,6 @@ void LldbTest::testVariablesQuicklySwitchFrame()
     WAIT_FOR_STATE(session, DebugSession::EndedState);
 }
 
-void LldbTest::testVariablesNonascii()
-{
-    TestDebugSession *session = new TestDebugSession;
-    TestLaunchConfiguration cfg(findExecutable("lldb_debugeeqt"));
-
-    session->variableController()->setAutoUpdate(KDevelop::IVariableController::UpdateLocals);
-
-    QString fileName = findSourceFile("debugeeqt.cpp");
-    breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 30);
-
-    QVERIFY(session->startDebugging(&cfg, m_iface));
-    WAIT_FOR_STATE_AND_IDLE(session, DebugSession::PausedState);
-
-    QCOMPARE(session->currentLine(), 30);
-    COMPARE_DATA(localVariableIndexAt(0, 1), QString("\"\u4f60\u597d\u4e16\u754c\""));
-
-    session->run();
-    WAIT_FOR_STATE(session, DebugSession::EndedState);
-}
-
 void LldbTest::testSwitchFrameLldbConsole()
 {
     TestDebugSession *session = new TestDebugSession;
