@@ -1,21 +1,15 @@
 {% load kdev_filters %}
-/*
-
- {{ license|lines_prepend:" * " }}
- */
+{% include "license_header_cpp.txt" %}
 
 
 #include "{{ output_file_header }}"
 
 
-#include <qtest_kde.h>
-
-
 #include <tests/testcore.h>
 #include <tests/autotestshell.h>
 
 
-QTEST_KDEMAIN({{ name }}, NoGUI);
+QTEST_GUILESS_MAIN({{ name }});
 
 
 using namespace KDevelop;
@@ -43,5 +37,3 @@ void {{ name }}::{{ case }}()
 }
 
 {% endfor %}
-
-#include "{{ output_file_header|cut:".h"|cut:".hpp" }}.moc"
