@@ -27,6 +27,7 @@
 
 #include <serialization/indexedstring.h>
 #include <language/editor/documentrange.h>
+#include <language/duchain/stringhelpers.h>
 
 #include <clang-c/Index.h>
 
@@ -55,7 +56,7 @@ CXCursor ClangUtils::getCXCursor(int line, int column, const CXTranslationUnit&
 
 KTextEditor::Range ClangUtils::rangeForIncludePathSpec(const QString& line, const KTextEditor::Range& originalRange)
 {
-    static const QRegularExpression pattern(QStringLiteral("^\\s*#include"));
+    static const QRegularExpression pattern(QStringLiteral("^\\s*(#include|#import)"));
     if (!line.contains(pattern)) {
         return KTextEditor::Range::invalid();
     }
@@ -264,6 +265,20 @@ QString ClangUtils::getCursorSignature(CXCursor cursor, const QString& scope, co
     return ret;
 }
 
+QStringList ClangUtils::templateArgumentTypes(CXCursor cursor)
+{
+    CXType typeList = clang_getCursorType(cursor);
+    int templateArgCount = clang_Type_getNumTemplateArguments(typeList);
+    QStringList types;
+    types.reserve(templateArgCount);
+    for (int i = 0; i < templateArgCount; ++i) {
+        ClangString clangString(clang_getTypeSpelling(clang_Type_getTemplateArgumentAsType(typeList, i)));
+        types.append(clangString.toString());
+    }
+
+    return types;
+}
+
 QByteArray ClangUtils::getRawContents(CXTranslationUnit unit, CXSourceRange range)
 {
     const auto rangeStart = clang_getRangeStart(range);
@@ -278,9 +293,15 @@ QByteArray ClangUtils::getRawContents(CXTranslationUnit unit, CXSourceRange rang
         const auto location = ClangLocation(clang_getTokenLocation(unit, token));
         unsigned int offset;
         clang_getFileLocation(location, nullptr, nullptr, nullptr, &offset);
-        Q_ASSERT(offset >= start);
+        Q_ASSERT(offset >= start); // TODO: Sometimes hit, see bug 357585
+        if (offset < start)
+            return {};
+
         const int fillCharacters = offset - start - result.size();
         Q_ASSERT(fillCharacters >= 0);
+        if (fillCharacters < 0)
+            return {};
+
         result.append(QByteArray(fillCharacters, ' '));
         const auto spelling = clang_getTokenSpelling(unit, token);
         result.append(clang_getCString(spelling));
@@ -299,8 +320,11 @@ bool ClangUtils::isExplicitlyDefaultedOrDeleted(CXCursor cursor)
         return true;
     }
 
-    // TODO: expose clang::FunctionDecl::isExplicitlyDefaulted() in libclang
-    // For symmetry we should probably also expose clang::FunctionDecl::isDeleted()
+#if CINDEX_VERSION_MINOR >= 34
+    if (clang_CXXMethod_isDefaulted(cursor)) {
+        return true;
+    }
+#else
     auto declCursor = clang_getCanonicalCursor(cursor);
     CXTranslationUnit tu = clang_Cursor_getTranslationUnit(declCursor);
     ClangTokens tokens(tu, clang_getCursorExtent(declCursor));
@@ -354,5 +378,28 @@ bool ClangUtils::isExplicitlyDefaultedOrDeleted(CXCursor cursor)
             }
         }
     }
+#endif
     return false;
 }
+
+ClangUtils::SpecialQtAttributes ClangUtils::specialQtAttributes(CXCursor cursor)
+{
+    // check for our injected attributes to detect Qt signals and slots
+    // see also the contents of wrappedQtHeaders/QtCore/qobjectdefs.h
+    SpecialQtAttributes qtAttribute = NoQtAttribute;
+    if (cursor.kind == CXCursor_CXXMethod) {
+        clang_visitChildren(cursor, [] (CXCursor cursor, CXCursor /*parent*/, CXClientData data) -> CXChildVisitResult {
+            if (cursor.kind == CXCursor_AnnotateAttr) {
+                auto retVal = static_cast<SpecialQtAttributes*>(data);
+                ClangString attribute(clang_getCursorDisplayName(cursor));
+                if (attribute.c_str() == QByteArrayLiteral("qt_signal")) {
+                    *retVal = QtSignalAttribute;
+                } else if (attribute.c_str() == QByteArrayLiteral("qt_slot")) {
+                    *retVal = QtSlotAttribute;
+                }
+            }
+            return CXChildVisit_Break;
+        }, &qtAttribute);
+    }
+    return qtAttribute;
+}
