@@ -131,12 +131,17 @@ TreeItem* manualRootItem(TreeItem* root)
 
 CompilersModel::CompilersModel(QObject* parent)
     : QAbstractItemModel(parent)
-    , m_rootItem(new TreeItem( QList<QVariant>{i18n("Name"), i18n("Type")}))
+    , m_rootItem(new TreeItem({i18n("Name"), i18n("Type")}))
 {
     m_rootItem->appendChild(new TreeItem( QList<QVariant>{i18n("Auto-detected"), QString()}, m_rootItem));
     m_rootItem->appendChild(new TreeItem( QList<QVariant>{i18n("Manual"), QString()}, m_rootItem));
 }
 
+CompilersModel::~CompilersModel()
+{
+    delete m_rootItem;
+}
+
 QVariant CompilersModel::data(const QModelIndex& index, int role) const
 {
     if (!index.isValid() || (role != Qt::DisplayRole && role != CompilerDataRole)) {
