@@ -58,6 +58,7 @@ ProjectPathsWidget::ProjectPathsWidget( QWidget* parent )
 
     ui->addPath->setIcon(QIcon::fromTheme("list-add"));
     ui->removePath->setIcon(QIcon::fromTheme("list-remove"));
+    ui->batchEdit->setIcon(QIcon::fromTheme(QStringLiteral("format-list-unordered")));
 
     // hack taken from kurlrequester, make the buttons a bit less in height so they better match the url-requester
     ui->addPath->setFixedHeight( ui->projectPaths->sizeHint().height() );
@@ -177,7 +178,7 @@ void ProjectPathsWidget::clear()
 void ProjectPathsWidget::addProjectPath()
 {
     const QUrl directory = pathsModel->data(pathsModel->index(0, 0), ProjectPathsModel::FullUrlDataRole).value<QUrl>();
-    QFileDialog dlg(this, tr("Select Project Path"), directory.toLocalFile());
+    QFileDialog dlg(this, i18n("Select Project Path"), directory.toLocalFile());
     dlg.setFileMode(QFileDialog::Directory);
     dlg.setOption(QFileDialog::ShowDirsOnly);
     dlg.exec();
@@ -230,7 +231,7 @@ void ProjectPathsWidget::batchEdit()
         auto defines = pathsModel->data(midx, ProjectPathsModel::DefinesDataRole).value<Defines>();
 
         for (auto it = defines.constBegin(); it != defines.constEnd(); it++) {
-            be.textEdit->append(it.key() + "=" + it.value());
+            be.textEdit->appendPlainText(it.key() + "=" + it.value());
         }
 
         dialog.setWindowTitle(i18n("Edit defined macros"));
