@@ -84,12 +84,8 @@ CMakeManager::CMakeManager( QObject* parent, const QVariantList& )
     : KDevelop::AbstractFileManagerPlugin( "kdevcmakemanager", parent )
     , m_filter( new ProjectFilterManager( this ) )
 {
-    KDEV_USE_EXTENSION_INTERFACE( KDevelop::IBuildSystemManager )
-    KDEV_USE_EXTENSION_INTERFACE( KDevelop::IProjectFileManager )
-    KDEV_USE_EXTENSION_INTERFACE( KDevelop::ILanguageSupport )
-    KDEV_USE_EXTENSION_INTERFACE( ICMakeManager)
-
-    if (hasError()) {
+    if (CMake::findExecutable().isEmpty()) {
+        setErrorDescription(i18n("Unable to find cmake executable. Is it installed on the system?"));
         m_highlight = nullptr;
         return;
     }
@@ -107,16 +103,6 @@ CMakeManager::CMakeManager( QObject* parent, const QVariantList& )
 //     connect(m_fileSystemChangeTimer,SIGNAL(timeout()),SLOT(filesystemBuffererTimeout()));
 }
 
-bool CMakeManager::hasError() const
-{
-    return CMake::findExecutable().isEmpty();
-}
-
-QString CMakeManager::errorDescription() const
-{
-    return hasError() ? i18n("cmake is not installed") : QString();
-}
-
 CMakeManager::~CMakeManager()
 {
     parseLock()->lockForWrite();
@@ -124,7 +110,7 @@ CMakeManager::~CMakeManager()
     parseLock()->unlock();
 }
 
-bool CMakeManager::hasIncludesOrDefines(ProjectBaseItem* item) const
+bool CMakeManager::hasBuildInfo(ProjectBaseItem* item) const
 {
     return m_projects[item->project()].jsonData.files.contains(item->path());
 }
@@ -234,6 +220,11 @@ Path::List CMakeManager::includeDirectories(KDevelop::ProjectBaseItem *item) con
     return fileInformation(item).includes;
 }
 
+Path::List CMakeManager::frameworkDirectories(KDevelop::ProjectBaseItem *item) const
+{
+    return fileInformation(item).frameworkDirectories;
+}
+
 QHash<QString, QString> CMakeManager::defines(KDevelop::ProjectBaseItem *item ) const
 {
     return fileInformation(item).defines;
@@ -722,7 +713,7 @@ bool CMakeManager::addFilesToTarget(const QList< ProjectFileItem* > &/*_files*/,
 QWidget* CMakeManager::specialLanguageObjectNavigationWidget(const QUrl &url, const KTextEditor::Cursor& position)
 {
     KDevelop::TopDUContextPointer top= TopDUContextPointer(KDevelop::DUChain::self()->chainForDocument(url));
-    Declaration *decl=0;
+    Declaration *decl=nullptr;
     if(top)
     {
         int useAt=top->findUseAt(top->transformToLocalRevision(position));
@@ -733,7 +724,7 @@ QWidget* CMakeManager::specialLanguageObjectNavigationWidget(const QUrl &url, co
         }
     }
 
-    CMakeNavigationWidget* doc=0;
+    CMakeNavigationWidget* doc=nullptr;
     if(decl)
     {
         doc=new CMakeNavigationWidget(top, decl);
