@@ -24,7 +24,7 @@
 #include <QString>
 #include <QStringList>
 #include <QHash>
-#include <QStack>
+#include <util/stack.h>
 
 #include "cmakeastvisitor.h"
 #include "cmaketypes.h"
@@ -47,55 +47,55 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
         explicit CMakeProjectVisitor(const QString& root, KDevelop::ReferencedTopDUContext parent);
         virtual ~CMakeProjectVisitor() {}
         
-        virtual int visit( const CustomCommandAst * ) override;
-        virtual int visit( const CustomTargetAst * ) override;
-        virtual int visit( const AddDefinitionsAst * ) override;
-        virtual int visit( const AddTestAst * ) override;
-        virtual int visit( const AddExecutableAst * ) override;
-        virtual int visit( const AddLibraryAst * ) override;
-        virtual int visit( const AddSubdirectoryAst * ) override;
-        virtual int visit( const IncludeDirectoriesAst * ) override;
-        virtual int visit( const IncludeAst * ) override;
-        virtual int visit( const MacroCallAst * call) override;
-        virtual int visit( const FindPackageAst * ) override;
-        virtual int visit( const MarkAsAdvancedAst * ) override;
-        virtual int visit( const FindProgramAst * ) override;
-        virtual int visit( const FunctionAst * ) override;
-        virtual int visit( const FindPathAst * ) override;
-        virtual int visit( const FindLibraryAst * ) override;
-        virtual int visit( const FindFileAst * ) override;
-        virtual int visit( const IfAst * ) override;
-        virtual int visit( const ExecProgramAst * ) override;
-        virtual int visit( const ExecuteProcessAst * ) override;
-        virtual int visit( const FileAst * ) override;
-        virtual int visit( const MessageAst * ) override;
-        virtual int visit( const MathAst * ) override;
-        virtual int visit( const MacroAst * ) override;
-        virtual int visit( const ListAst * ) override;
-        virtual int visit( const GetDirPropertyAst * ) override;
-        virtual int visit( const GetFilenameComponentAst * ) override;
-        virtual int visit( const GetSourceFilePropAst * ) override;
-        virtual int visit( const GetTargetPropAst * ) override;
-        virtual int visit( const OptionAst * ) override;
-        virtual int visit( const SetAst * ) override;
-        virtual int visit( const ForeachAst * ) override;
-        virtual int visit( const ProjectAst * ) override;
-        virtual int visit( const SetPropertyAst* ) override;
-        virtual int visit( const SetTargetPropsAst * ) override;
-        virtual int visit( const SetDirectoryPropsAst * ) override;
-        virtual int visit( const StringAst * ) override;
-        virtual int visit( const SubdirsAst * ) override;
-        virtual int visit( const SetTestsPropsAst* ) override;
-        virtual int visit( const TargetLinkLibrariesAst * ) override;
-        virtual int visit( const TargetIncludeDirectoriesAst* ) override;
-        virtual int visit( const TryCompileAst * ) override;
-        virtual int visit( const GetCMakePropertyAst * ) override;
-        virtual int visit( const GetPropertyAst* ) override;
-        virtual int visit( const RemoveDefinitionsAst * ) override;
-        virtual int visit( const SeparateArgumentsAst * ) override;
-        virtual int visit( const UnsetAst * ) override;
-        virtual int visit( const WhileAst * ) override;
-        virtual int visit( const CMakeAst * ) override;
+        int visit( const CustomCommandAst * ) override;
+        int visit( const CustomTargetAst * ) override;
+        int visit( const AddDefinitionsAst * ) override;
+        int visit( const AddTestAst * ) override;
+        int visit( const AddExecutableAst * ) override;
+        int visit( const AddLibraryAst * ) override;
+        int visit( const AddSubdirectoryAst * ) override;
+        int visit( const IncludeDirectoriesAst * ) override;
+        int visit( const IncludeAst * ) override;
+        int visit( const MacroCallAst * call) override;
+        int visit( const FindPackageAst * ) override;
+        int visit( const MarkAsAdvancedAst * ) override;
+        int visit( const FindProgramAst * ) override;
+        int visit( const FunctionAst * ) override;
+        int visit( const FindPathAst * ) override;
+        int visit( const FindLibraryAst * ) override;
+        int visit( const FindFileAst * ) override;
+        int visit( const IfAst * ) override;
+        int visit( const ExecProgramAst * ) override;
+        int visit( const ExecuteProcessAst * ) override;
+        int visit( const FileAst * ) override;
+        int visit( const MessageAst * ) override;
+        int visit( const MathAst * ) override;
+        int visit( const MacroAst * ) override;
+        int visit( const ListAst * ) override;
+        int visit( const GetDirPropertyAst * ) override;
+        int visit( const GetFilenameComponentAst * ) override;
+        int visit( const GetSourceFilePropAst * ) override;
+        int visit( const GetTargetPropAst * ) override;
+        int visit( const OptionAst * ) override;
+        int visit( const SetAst * ) override;
+        int visit( const ForeachAst * ) override;
+        int visit( const ProjectAst * ) override;
+        int visit( const SetPropertyAst* ) override;
+        int visit( const SetTargetPropsAst * ) override;
+        int visit( const SetDirectoryPropsAst * ) override;
+        int visit( const StringAst * ) override;
+        int visit( const SubdirsAst * ) override;
+        int visit( const SetTestsPropsAst* ) override;
+        int visit( const TargetLinkLibrariesAst * ) override;
+        int visit( const TargetIncludeDirectoriesAst* ) override;
+        int visit( const TryCompileAst * ) override;
+        int visit( const GetCMakePropertyAst * ) override;
+        int visit( const GetPropertyAst* ) override;
+        int visit( const RemoveDefinitionsAst * ) override;
+        int visit( const SeparateArgumentsAst * ) override;
+        int visit( const UnsetAst * ) override;
+        int visit( const WhileAst * ) override;
+        int visit( const CMakeAst * ) override;
         
         
         void setCacheValues( CacheValues* cache);
@@ -178,7 +178,7 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
         bool haveToFind(const QString &varName);
         void createDefinitions(const CMakeAst* ast);
         void createUses(const CMakeFunctionDesc& ast);
-        void printBacktrace(const QStack<VisitorState> &backtrace);
+        void printBacktrace(const KDevelop::Stack<VisitorState> &backtrace);
         VisitorState stackTop() const;
         QStringList dependees(const QString& s) const;
         int declareFunction(Macro m, const CMakeFileContent& content, int initial, const QString& end);
@@ -193,7 +193,7 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
         QHash<QString, QStringList> m_generatedFiles;
         QHash<QString, Target> m_targetForId;
         
-        QStack<VisitorState> m_backtrace;
+        KDevelop::Stack<VisitorState> m_backtrace;
         QString m_root;
         VariableMap *m_vars;
         MacroMap *m_macros;
