@@ -24,14 +24,17 @@
 #include <QVector>
 #include <QList>
 #include <QStringList>
-#include <KUrl>
+#include <QUrl>
+#include <QMetaType>
 
 struct CustomBuildSystemTool
 {
     enum ActionType { Build = 0, Configure, Install, Clean, Prune, Undefined };
+    static QString toolName(ActionType type);
+
     CustomBuildSystemTool() : enabled( false ), type( Undefined ) {}
     bool enabled;
-    KUrl executable;
+    QUrl executable;
     QString arguments;
     QString envGrp;
     ActionType type;
@@ -42,7 +45,7 @@ Q_DECLARE_METATYPE( CustomBuildSystemTool )
 struct CustomBuildSystemConfig
 {
     QString title;
-    KUrl buildDir;
+    QUrl buildDir;
     QVector<CustomBuildSystemTool> tools;
 
     CustomBuildSystemConfig()
